@@ -1,9 +1,6 @@
 """ViSP instrument polarization task."""
 import logging
 from collections import defaultdict
-from typing import Dict
-from typing import List
-from typing import Tuple
 
 import numpy as np
 from astropy.io import fits
@@ -73,6 +70,7 @@ class InstrumentPolarizationCalibration(
         logging.info(
             f"Demodulation matrices will span FOV with shape {(self.parameters.polcal_num_spectral_bins, self.parameters.polcal_num_spatial_bins)}"
         )
+        remove_I_trend = self.parameters.pac_remove_linear_I_trend
         for beam in range(1, self.constants.num_beams + 1):
             with self.apm_processing_step(f"Reducing CS steps for {beam = }"):
                 local_reduced_arrays, global_reduced_arrays = self.reduce_cs_steps(beam)
@@ -80,9 +78,13 @@ class InstrumentPolarizationCalibration(
             with self.apm_processing_step(f"Fit CU parameters for {beam = }"):
                 logging.info(f"Fit CU parameters for {beam = }")
                 local_dresser = Dresser()
-                local_dresser.add_drawer(Drawer(local_reduced_arrays))
+                local_dresser.add_drawer(
+                    Drawer(local_reduced_arrays, remove_I_trend=remove_I_trend)
+                )
                 global_dresser = Dresser()
-                global_dresser.add_drawer(Drawer(global_reduced_arrays))
+                global_dresser.add_drawer(
+                    Drawer(global_reduced_arrays, remove_I_trend=remove_I_trend)
+                )
                 pac_fitter = PolcalFitter(
                     local_dresser=local_dresser,
                     global_dresser=global_dresser,
@@ -128,7 +130,7 @@ class InstrumentPolarizationCalibration(
 
     def reduce_cs_steps(
         self, beam: int
-    ) -> Tuple[Dict[int, List[VispL0FitsAccess]], Dict[int, List[VispL0FitsAccess]]]:
+    ) -> tuple[dict[int, list[VispL0FitsAccess]], dict[int, list[VispL0FitsAccess]]]:
         """
         Reduce all of the data for the cal sequence steps for this beam.
 
@@ -146,6 +148,11 @@ class InstrumentPolarizationCalibration(
         local_reduced_array_dict = defaultdict(list)
         global_reduced_array_dict = defaultdict(list)
 
+        try:
+            background_array = self.intermediate_frame_helpers_load_background_array(beam=beam)
+        except StopIteration:
+            raise ValueError(f"No background light found for {beam = }")
+
         for modstate in range(1, self.constants.num_modstates + 1):
             angle = self.intermediate_frame_helpers_load_angle(beam=beam)
             state_offset = self.intermediate_frame_helpers_load_state_offset(
@@ -167,6 +174,7 @@ class InstrumentPolarizationCalibration(
                     local_obj, global_obj = self.reduce_single_step(
                         beam,
                         dark_array,
+                        background_array,
                         modstate,
                         cs_step,
                         exp_time,
@@ -183,13 +191,14 @@ class InstrumentPolarizationCalibration(
         self,
         beam: int,
         dark_array: np.ndarray,
+        background_array: np.ndarray,
         modstate: int,
         cs_step: int,
         exp_time: float,
         angle: float,
         state_offset: np.ndarray,
         spec_shift: np.ndarray,
-    ) -> Tuple[VispL0FitsAccess, VispL0FitsAccess]:
+    ) -> tuple[VispL0FitsAccess, VispL0FitsAccess]:
         """
         Reduce a single calibration step for this beam, cs step and modulator state.
 
@@ -242,11 +251,23 @@ class InstrumentPolarizationCalibration(
         with self.apm_processing_step(f"Apply basic corrections for {apm_str}"):
             dark_corrected_array = subtract_array_from_arrays(avg_inst_pol_cal_array, dark_array)
 
+            background_corrected_array = subtract_array_from_arrays(
+                dark_corrected_array, background_array
+            )
+
+            lamp_gain_array = self.intermediate_frame_helpers_load_lamp_gain_array(
+                beam=beam, modstate=modstate
+            )
+
+            lamp_corrected_array = divide_arrays_by_array(
+                background_corrected_array, lamp_gain_array
+            )
+
             solar_gain_array = self.intermediate_frame_helpers_load_solar_gain_array(
                 beam=beam, modstate=modstate
             )
             gain_corrected_array = next(
-                divide_arrays_by_array(dark_corrected_array, solar_gain_array)
+                divide_arrays_by_array(lamp_corrected_array, solar_gain_array)
             )
 
             geo_corrected_array = self.corrections_correct_geometry(
@@ -331,6 +352,12 @@ class InstrumentPolarizationCalibration(
             bins_2=self.parameters.polcal_num_spatial_bins,
             bin_1_type="spectral",
             bin_2_type="spatial",
+            ## This is a bit of a hack and thus needs some explanation
+            # By using the ``skip_recording_constant_pars`` switch we DON'T record the "polcal constant parameters" metric
+            # for beam 2. This is because both beam 1 and beam 2 will have the same table. The way `*-common` is built
+            # it will look for all metrics for both beam 1 and beam 2 so if we did save that metric for beam 2 then the
+            # table would show up twice in the quality report. The following line avoids that.
+            skip_recording_constant_pars=beam != 1,
         )
 
     def save_intermediate_polcal_files(
@@ -425,7 +452,7 @@ class InstrumentPolarizationCalibration(
         """Record the shape of a single beam as a class property."""
         self.single_beam_shape = array.shape
 
-    def _resize_polcal_array(self, array: np.ndarray, output_shape: Tuple[int, ...]) -> np.ndarray:
+    def _resize_polcal_array(self, array: np.ndarray, output_shape: tuple[int, ...]) -> np.ndarray:
         return next(
             resize_arrays(array, output_shape, order=self.parameters.polcal_demod_upsample_order)
         )
