@@ -57,22 +57,25 @@ class CalibrationCollection:
         logging.info(f"All x shifts: {all_x_shifts}")
         logging.info(f"All y shifts: {all_y_shifts}")
 
-        # The np.abs is necessary to find that largest magnitude shift
-        max_x = all_x_shifts[np.argmax(np.abs(all_x_shifts))]
-        max_y = all_y_shifts[np.argmax(np.abs(all_y_shifts))]
+        # The amount we need to "slice in" from the front of the array is simply the maximum positive shift
+        # The call to `np.ceil` ensures that the integer rounding doesn't allow non-overlap regions to leak in.
+        max_x = int(np.ceil(np.max(all_x_shifts)))
+        max_y = int(np.ceil(np.max(all_y_shifts)))
 
-        # The overlap region is simply the region defined by the largest slices in from the edges
-        if max_x < 0:
-            # Negative shifts mean we need to chop in from the "end" of the array
-            x_slice = slice(None, int(np.floor(max_x)))
-        else:
-            # Positive shifts mean we start in from the "start" of the array
-            x_slice = slice(int(np.ceil(max_x)), None)
+        # The amount we need to "chop off" the end of the array is the most negative negative shift.
+        #
+        # Here we rely on the fact that the fiducial array's shift is *always* (0, 0)
+        #  (see `geometric.compute_modstate_offset`). Thus, if there are no negative shifts then the following lines
+        #  will result in None. This is required for slicing because array[x:0] is no good. So if the min is 0 then we
+        #  end up with array[x:None] which goes all the way to the end of the array.
+        #
+        # The call to `np.floor` ensures that the integer rounding doesn't allow non-overlap regions to leak in.
+        #  (because more negative slices will cut out more data).
+        min_x = int(np.floor(np.min(all_x_shifts))) or None
+        min_y = int(np.floor(np.min(all_y_shifts))) or None
 
-        if max_y < 0:
-            y_slice = slice(None, int(np.floor(max_y)))
-        else:
-            y_slice = slice(int(np.ceil(max_y)), None)
+        x_slice = slice(max_x, min_x)
+        y_slice = slice(max_y, min_y)
 
         return x_slice, y_slice
 
@@ -620,8 +623,10 @@ class ScienceCalibration(
 
         # Adjust the CRPIX values if the beam overlap slicing chopped from the start of the array
         x_slice, y_slice = calibrations.beams_overlap_slice
+
+        # This if catches 0's and Nones
         if x_slice.start:
-            # .start will only be non-None if the slice is from the start. In this case we need to update the WCS
+            # .start will only be non-None or 0 if the slice is from the start. In this case we need to update the WCS
             logging.info(
                 f"Adjusting CRPIX2 from {header['CRPIX2']} to {header['CRPIX2'] - x_slice.start}"
             )
@@ -683,7 +688,7 @@ class ScienceCalibration(
             VispTag.raster_step(raster_step),
             VispTag.map_scan(map_scan),
         ]
-        hdul = fits.HDUList([fits.PrimaryHDU(header=header, data=data)])
+        hdul = fits.HDUList([fits.PrimaryHDU(), fits.CompImageHDU(header=header, data=data)])
         self.fits_data_write(hdu_list=hdul, tags=tags)
 
         filename = next(self.read(tags=tags))
