@@ -57,30 +57,44 @@ class VispWriteL1Frame(WriteL1Frame):
         if stokes.upper() not in self.constants.stokes_params:
             raise ValueError("The stokes parameter must be one of I, Q, U, V")
 
-        # ---Spatial 1---
-        header["DNAXIS1"] = header["NAXIS1"]
-        header["DTYPE1"] = "SPATIAL"
-        header["DPNAME1"] = "spatial along slit"
-        header["DWNAME1"] = "helioprojective latitude"
-        header["DUNIT1"] = header["CUNIT1"]
-
-        # ---Spectral---
-        header["DNAXIS2"] = header["NAXIS2"]
-        header["DTYPE2"] = "SPECTRAL"
-        header["DPNAME2"] = "dispersion axis"
-        header["DWNAME2"] = "wavelength"
-        header["DUNIT2"] = header["CUNIT2"]
-
-        # ---Spatial 2---
-        header["DNAXIS3"] = self.constants.num_raster_steps
-        header["DTYPE3"] = "SPATIAL"
-        header["DPNAME3"] = "raster scan step number"
-        header["DWNAME3"] = "helioprojective longitude"
-        header["DUNIT3"] = header["CUNIT3"]
-        # Raster position in dataset
-        header["DINDEX3"] = (
-            header["VSPSTP"] + 1
-        )  # Current position in raster scan which counts from zero
+        # Dynamically assign dataset axes based on CTYPEs in the L0 headers
+        axis_types = [
+            self.constants.axis_1_type,
+            self.constants.axis_2_type,
+            self.constants.axis_3_type,
+        ]
+        for i, axis_type in enumerate(axis_types, start=1):
+            if axis_type == "HPLT-TAN":
+                header[f"DNAXIS{i}"] = header[f"NAXIS{i}"]
+                header[f"DTYPE{i}"] = "SPATIAL"
+                header[f"DPNAME{i}"] = "spatial along slit"
+                header[f"DWNAME{i}"] = "helioprojective latitude"
+                header[f"DUNIT{i}"] = header[f"CUNIT{i}"]
+            elif axis_type == "AWAV":
+                header[f"DNAXIS{i}"] = header[f"NAXIS{i}"]
+                header[f"DTYPE{i}"] = "SPECTRAL"
+                header[f"DPNAME{i}"] = "dispersion axis"
+                header[f"DWNAME{i}"] = "wavelength"
+                header[f"DUNIT{i}"] = header[f"CUNIT{i}"]
+                # The wavemin and wavemax assume that all frames in a dataset have identical wavelength axes
+                header["WAVEMIN"] = header[f"CRVAL{i}"] - (
+                    header[f"CRPIX{i}"] * header[f"CDELT{i}"]
+                )
+                header["WAVEMAX"] = header[f"CRVAL{i}"] + (
+                    (header[f"NAXIS{i}"] - header[f"CRPIX{i}"]) * header[f"CDELT{i}"]
+                )
+            elif axis_type == "HPLN-TAN":
+                header[f"DNAXIS{i}"] = self.constants.num_raster_steps
+                header[f"DTYPE{i}"] = "SPATIAL"
+                header[f"DPNAME{i}"] = "raster scan step number"
+                header[f"DWNAME{i}"] = "helioprojective longitude"
+                header[f"DUNIT{i}"] = header[f"CUNIT{i}"]
+                # Current position in raster scan which counts from zero
+                header[f"DINDEX{i}"] = header["VSPSTP"] + 1
+            else:
+                raise ValueError(
+                    f"Unexpected axis type. Expected ['HPLT-TAN', 'AWAV', 'HPLN-TAN']. Got {axis_type}"
+                )
 
         # Set the base number of dataset axes to 3
         num_axis = 3
@@ -121,11 +135,6 @@ class VispWriteL1Frame(WriteL1Frame):
         header["WAVEBAND"] = self.constants.spectral_line
         header["WAVEUNIT"] = -9  # nanometers
         header["WAVEREF"] = "Air"
-        # The wavemin and wavemax assume that all frames in a dataset have identical wavelength axes
-        header["WAVEMIN"] = header["CRVAL1"] - (header["CRPIX1"] * header["CDELT1"])
-        header["WAVEMAX"] = header["CRVAL1"] + (
-            (header["NAXIS1"] - header["CRPIX1"]) * header["CDELT1"]
-        )
 
         # Binning headers
         header["NBIN1"] = 1
@@ -149,48 +158,4 @@ class VispWriteL1Frame(WriteL1Frame):
         header.pop("BSCALE", None)
         # Make sure that NAXIS is set to the shape of the data in case of squeezing
         header["NAXIS"] = len(data.shape)
-        # Check that the WCS headers are in the right order
-        if header["CTYPE1"] == "AWAV":  # Then the order is wrong
-            header = self.transpose_wcs_keys(header=header)
-        return header
-
-    @staticmethod
-    def transpose_wcs_keys(header: fits.Header) -> fits.Header:
-        """
-        In early DKIST operations, some WCS keys and the PCi_j matrix were incorrectly ordered.
-
-        This function transposes them to reverse it.
-        """
-        logging.info(f"Transposing axes 1 and 2 of the WCS headers")
-
-        # What keys need to be transposed? Substitute "n" for the axis number.
-        # All FITS keywords are supposed to be uppercase so using lowercase "n" should be OK
-        # CRPIXn is excluded from this list as it is observed to be in the
-        # correct order already (does not need transposing.)
-        key_list = [
-            "CRDATEn",
-            "CRVALn",
-            "CDELTn",
-            "CUNITn",
-            "CTYPEn",
-        ]
-
-        # Gather the values from the key_list keywords and swap them in place
-        for key in key_list:
-            for suffix in ["", "A"]:
-                key_1 = f"{key}{suffix}".replace("n", "1")
-                key_2 = f"{key}{suffix}".replace("n", "2")
-                try:
-                    header[key_1], header[key_2] = header[key_2], header[key_1]
-                except KeyError:  # The "A" variant of keywords are not required
-                    logging.info(
-                        f"Keywords {key_1} and {key_2} were not switched as they do not exist in this frame."
-                    )
-
-        # The PC matrix is observed to be in a different order.
-        # It is in the lt, ln, wave order, when we want it in the lt, wave, ln order.
-        for n in range(1, 4):
-            header[f"PC2_{n}"], header[f"PC3_{n}"] = header[f"PC3_{n}"], header[f"PC2_{n}"]
-        # Note also that the reordered value of PC2_2 (i.e. wave) is probably wrong and should be one
-
         return header
