@@ -94,6 +94,22 @@ class LoadDarkCal(LoadTaskTags):
         return "dark_cal.asdf"
 
 
+class SaveBackgroundCal(SaveTaskTags):
+    @property
+    def task_str(self) -> str:
+        return "BACKGROUND"
+
+    @property
+    def relative_save_file(self) -> str:
+        return "background_cal.asdf"
+
+
+class LoadBackgroundCal(LoadTaskTags):
+    @property
+    def relative_save_file(self) -> str:
+        return "background_cal.asdf"
+
+
 class SaveLampCal(SaveTaskTags):
     @property
     def task_str(self) -> str:
