@@ -42,9 +42,9 @@ def background_testing_parameters(background_full_beam_shape) -> VispTestingPara
     num_wave = background_full_beam_shape[0]
     cont_idx = list(range(num_wave // 2))
     return VispTestingParameters(
-        visp_background_num_spatial_bins=1,
-        visp_background_wavelength_subsample_factor=20,
-        visp_background_num_fit_iterations=10,
+        visp_background_num_spatial_bins=WavelengthParameter(values=(1, 1, 1, 1)),
+        visp_background_wavelength_subsample_factor=WavelengthParameter(values=(20, 20, 20, 20)),
+        visp_background_num_fit_iterations=WavelengthParameter(values=(10, 10, 10, 10)),
         visp_background_continuum_index=WavelengthParameter(
             values=(cont_idx, cont_idx, cont_idx, cont_idx)
         ),
