@@ -1,7 +1,7 @@
 import pytest
 from dkist_processing_common._util.scratch import WorkflowFileSystem
-from dkist_processing_common.tasks import SubmitQuality
 
+from dkist_processing_visp.tasks.l1_output_data import VispSubmitQuality
 from dkist_processing_visp.tests.conftest import VispConstantsDb
 
 
@@ -18,7 +18,7 @@ def plot_data():
 def quality_task(tmp_path, recipe_run_id, init_visp_constants_db):
     constants_db = VispConstantsDb(NUM_MODSTATES=2, POLARIMETER_MODE="observe_polarimetric")
     init_visp_constants_db(recipe_run_id, constants_db)
-    with SubmitQuality(
+    with VispSubmitQuality(
         recipe_run_id=recipe_run_id,
         workflow_name="workflow_name",
         workflow_version="workflow_version",
@@ -33,6 +33,7 @@ def quality_task(tmp_path, recipe_run_id, init_visp_constants_db):
         task.constants._purge()
 
 
+# TODO: This is already tested in *-common. Does it need to be here?
 def test_build_report(quality_task, plot_data):
     """
     Given: a task with the QualityMixin and data on disk for multiple metrics
@@ -81,12 +82,10 @@ def test_build_report(quality_task, plot_data):
     task.quality_store_range(name="metric 3", warnings=["warning 3"])
     task.quality_store_health_status(values=["Good", "Good", "Good", "Good", "Good", "Ill"])
     task.quality_store_ao_status(values=[1, 1, 1, 1, 1, 0, 1, 1, 0, 1, 1, 1, 1, 1, 0])
-    task.quality_store_polarimetric_noise(datetimes=datetimes_a, values=values_a, stokes="Q")
-    task.quality_store_polarimetric_noise(datetimes=datetimes_a, values=values_a, stokes="U")
-    task.quality_store_polarimetric_noise(datetimes=datetimes_a, values=values_a, stokes="V")
-    task.quality_store_polarimetric_sensitivity(datetimes=datetimes_a, values=values_a)
-    task.quality_store_polarimetric_sensitivity(datetimes=datetimes_a, values=values_a)
-    task.quality_store_polarimetric_sensitivity(datetimes=datetimes_a, values=values_a)
+    task.quality_store_sensitivity(datetimes=datetimes_a, values=values_a, stokes="I")
+    task.quality_store_sensitivity(datetimes=datetimes_a, values=values_a, stokes="Q")
+    task.quality_store_sensitivity(datetimes=datetimes_a, values=values_a, stokes="U")
+    task.quality_store_sensitivity(datetimes=datetimes_a, values=values_a, stokes="V")
     task.quality_store_historical(name="hist 1", value=7)
     task.quality_store_historical(name="hist 2", value="abc")
     task.quality_store_historical(
@@ -94,8 +93,4 @@ def test_build_report(quality_task, plot_data):
     )
 
     report = task.quality_build_report()
-    assert len(report) == 19
-    assert report[-1]["name"] == "Warnings count"
-    assert (
-        report[-1]["statement"] == "6 warnings were raised during the calibration of this dataset"
-    )
+    assert len(report) == 15
