@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Tuple
+from unittest.mock import ANY
 from unittest.mock import patch
 
 import numpy as np
@@ -8,12 +8,12 @@ import pytest
 from astropy.io import fits
 from dkist_header_validator import spec122_validator
 from dkist_processing_common._util.scratch import WorkflowFileSystem
+from dkist_processing_common.tests.conftest import FakeGQLClient
 from dkist_processing_pac.fitter.polcal_fitter import PolcalFitter
 from dkist_processing_pac.input_data.dresser import Dresser
 
 from dkist_processing_visp.models.tags import VispTag
 from dkist_processing_visp.tasks.instrument_polarization import InstrumentPolarizationCalibration
-from dkist_processing_visp.tests.conftest import FakeGQLClient
 from dkist_processing_visp.tests.conftest import generate_fits_frame
 from dkist_processing_visp.tests.conftest import VispConstantsDb
 from dkist_processing_visp.tests.conftest import VispHeadersValidPolcalFrames
@@ -96,8 +96,8 @@ def instrument_polarization_calibration_task(
             mocker.patch(
                 "dkist_processing_visp.tasks.instrument_polarization.InstrumentPolarizationCalibration.save_intermediate_polcal_files"
             )
-            mocker.patch(
-                "dkist_processing_visp.tasks.instrument_polarization.InstrumentPolarizationCalibration.record_polcal_quality_metrics"
+            quality_metric_mocker = mocker.patch(
+                "dkist_processing_visp.tasks.instrument_polarization.InstrumentPolarizationCalibration.quality_store_polcal_results"
             )
             # Create fake geometric objects
             angle = np.array([0.0])
@@ -121,10 +121,27 @@ def instrument_polarization_calibration_task(
                     all_zeros, beam=beam, task="DARK", exposure_time=exposure_time
                 )
 
+                # BackgroundLight object
+                task.intermediate_frame_helpers_write_arrays(
+                    arrays=all_zeros, beam=beam, task="BACKGROUND"
+                )
+
             for beam in range(1, num_beams + 1):
-                # Create a fake solar gain array for this beam and modstate
+                # Create fake lamp and solar gain arrays for this beam and modstate
                 for modstate in range(1, num_modstates + 1):
                     gain_hdul = fits.HDUList([fits.PrimaryHDU(data=all_ones)])
+                    task.fits_data_write(
+                        hdu_list=gain_hdul,
+                        tags=[
+                            VispTag.intermediate(),
+                            VispTag.frame(),
+                            VispTag.task("LAMP_GAIN"),
+                            VispTag.beam(beam),
+                            VispTag.modstate(modstate),
+                            VispTag.exposure_time(exposure_time),
+                        ],
+                    )
+
                     task.fits_data_write(
                         hdu_list=gain_hdul,
                         tags=[
@@ -169,7 +186,7 @@ def instrument_polarization_calibration_task(
                         ],
                     )
 
-            yield task
+            yield task, quality_metric_mocker
         except:
             raise
         finally:
@@ -198,7 +215,7 @@ def instrument_polarization_calibration_task_with_no_data(
 
 
 @pytest.fixture()
-def full_beam_shape() -> Tuple[int, int]:
+def full_beam_shape() -> tuple[int, int]:
     return (100, 256)
 
 
@@ -216,7 +233,7 @@ def test_instrument_polarization_calibration_task(instrument_polarization_calibr
     """
     Given: An InstrumentPolarizationCalibration task
     When: Calling the task instance
-    Then: A demodulation matrix for each beam is produced
+    Then: A demodulation matrix for each beam is produced and the correct call to the quality storage system was made
     """
 
     mocker.patch(
@@ -224,11 +241,11 @@ def test_instrument_polarization_calibration_task(instrument_polarization_calibr
     )
 
     # When
-    task = instrument_polarization_calibration_task
+    task, quality_mocker = instrument_polarization_calibration_task
     task()
 
     # Then
-    for beam in range(1, 2 + 1):
+    for beam in [1, 2]:
         tags = [
             VispTag.intermediate(),
             VispTag.task("DEMOD_MATRICES"),
@@ -236,6 +253,16 @@ def test_instrument_polarization_calibration_task(instrument_polarization_calibr
         ]
         assert len(list(task.read(tags=tags))) == 1
 
+        quality_mocker.assert_any_call(
+            polcal_fitter=ANY,
+            label=f"Beam {beam}",
+            bins_1=task.parameters.polcal_num_spectral_bins,
+            bins_2=task.parameters.polcal_num_spatial_bins,
+            bin_1_type="spectral",
+            bin_2_type="spatial",
+            skip_recording_constant_pars=beam == 2,
+        )
+
 
 def test_reshape_demod_matrices(
     instrument_polarization_calibration_task_with_no_data,
