@@ -8,6 +8,7 @@ from dkist_processing_common.tasks import TransferL1Data
 from dkist_processing_core import Workflow
 
 from dkist_processing_visp.tasks.assemble_movie import AssembleVispMovie
+from dkist_processing_visp.tasks.background_light import BackgroundLightCalibration
 from dkist_processing_visp.tasks.dark import DarkCalibration
 from dkist_processing_visp.tasks.geometric import GeometricCalibration
 from dkist_processing_visp.tasks.instrument_polarization import InstrumentPolarizationCalibration
@@ -22,17 +23,22 @@ from dkist_processing_visp.tasks.solar import SolarCalibration
 from dkist_processing_visp.tasks.write_l1 import VispWriteL1Frame
 
 l0_pipeline = Workflow(
-    process_category="visp",
-    process_name="l0_pipeline",
+    category="visp",
+    input_data="l0",
+    output_data="l1",
     workflow_package=__package__,
 )
 l0_pipeline.add_node(task=TransferL0Data, upstreams=None)
 l0_pipeline.add_node(task=ParseL0VispInputData, upstreams=TransferL0Data)
 l0_pipeline.add_node(task=VispL0QualityMetrics, upstreams=ParseL0VispInputData)
 l0_pipeline.add_node(task=DarkCalibration, upstreams=ParseL0VispInputData)
+l0_pipeline.add_node(task=BackgroundLightCalibration, upstreams=DarkCalibration)
 l0_pipeline.add_node(task=LampCalibration, upstreams=DarkCalibration)
 l0_pipeline.add_node(task=GeometricCalibration, upstreams=DarkCalibration)
-l0_pipeline.add_node(task=SolarCalibration, upstreams=[LampCalibration, GeometricCalibration])
+l0_pipeline.add_node(
+    task=SolarCalibration,
+    upstreams=[LampCalibration, GeometricCalibration, BackgroundLightCalibration],
+)
 l0_pipeline.add_node(task=InstrumentPolarizationCalibration, upstreams=SolarCalibration)
 l0_pipeline.add_node(task=ScienceCalibration, upstreams=InstrumentPolarizationCalibration)
 l0_pipeline.add_node(task=VispWriteL1Frame, upstreams=ScienceCalibration)
